@@ -360,7 +360,10 @@ class Generate_100_Keyword:
         self.spare_keyword_list = list(set(self.spare_keyword_list))
         print('===去重后总计关键词【%s】个===\n' %(len(self.spare_keyword_list)))
         print('========下方为匹配出的关键词覆盖========')
+        new_str_list = []
         for i in range(range_num):
-            new_str_list = Jieba_Word_algorithm(self.spare_keyword_list).class_generate_words()
-            print(new_str_list)
+            new_str_text = Jieba_Word_algorithm(self.spare_keyword_list).class_generate_words()
+            new_str_list.append(new_str_text)
+            print(new_str_text)
+        return new_str_list
 
